@@ -1,4 +1,9 @@
-/* $Id: functions.js 8985 2006-04-27 11:35:54Z nijel $ */
+/* vim: set expandtab sw=4 ts=4 sts=4: */
+/**
+ * general function, usally for data manipulation pages
+ *
+ * @version $Id: functions.js 11695 2008-11-02 06:54:27Z rajkissu $
+ */
 
 /**
  * @var sql_box_locked lock for the sqlbox textarea in the querybox/querywindow
@@ -46,11 +51,11 @@ function confirmLinkDropDB(theLink, theSqlQuery)
 {
     // Confirmation is not required in the configuration file
     // or browser is Opera (crappy js implementation)
-    if (confirmMsg == '' || typeof(window.opera) != 'undefined') {
+    if (PMA_messages['strDoYouReally'] == '' || typeof(window.opera) != 'undefined') {
         return true;
     }
 
-    var is_confirmed = confirm(confirmMsgDropDB + '\n' + confirmMsg + ' :\n' + theSqlQuery);
+    var is_confirmed = confirm(PMA_messages['strDropDatabaseStrongWarning'] + '\n' + PMA_messages['strDoYouReally'] + ' :\n' + theSqlQuery);
     if (is_confirmed) {
         theLink.href += '&is_js_confirmed=1';
     }
@@ -71,11 +76,11 @@ function confirmLink(theLink, theSqlQuery)
 {
     // Confirmation is not required in the configuration file
     // or browser is Opera (crappy js implementation)
-    if (confirmMsg == '' || typeof(window.opera) != 'undefined') {
+    if (PMA_messages['strDoYouReally'] == '' || typeof(window.opera) != 'undefined') {
         return true;
     }
 
-    var is_confirmed = confirm(confirmMsg + ' :\n' + theSqlQuery);
+    var is_confirmed = confirm(PMA_messages['strDoYouReally'] + ' :\n' + theSqlQuery);
     if (is_confirmed) {
         if ( typeof(theLink.href) != 'undefined' ) {
             theLink.href += '&is_js_confirmed=1';
@@ -125,7 +130,7 @@ function confirmAction(theMessage)
 function confirmQuery(theForm1, sqlQuery1)
 {
     // Confirmation is not required in the configuration file
-    if (confirmMsg == '') {
+    if (PMA_messages['strDoYouReally'] == '') {
         return true;
     }
 
@@ -137,10 +142,10 @@ function confirmQuery(theForm1, sqlQuery1)
     // js1.2+ -> validation with regular expressions
     else {
         // "DROP DATABASE" statement isn't allowed
-        if (noDropDbMsg != '') {
+        if (PMA_messages['strNoDropDatabases'] != '') {
             var drop_re = new RegExp('(^|;)\\s*DROP\\s+(IF EXISTS\\s+)?DATABASE\\s', 'i');
             if (drop_re.test(sqlQuery1.value)) {
-                alert(noDropDbMsg);
+                alert(PMA_messages['strNoDropDatabases']);
                 theForm1.reset();
                 sqlQuery1.focus();
                 return false;
@@ -154,16 +159,16 @@ function confirmQuery(theForm1, sqlQuery1)
         // For now, I just added a ^ to check for the statement at
         // beginning of expression
 
-        var do_confirm_re_0 = new RegExp('^DROP\\s+(IF EXISTS\\s+)?(TABLE|DATABASE)\\s', 'i');
-        var do_confirm_re_1 = new RegExp('^ALTER\\s+TABLE\\s+((`[^`]+`)|([A-Za-z0-9_$]+))\\s+DROP\\s', 'i');
-        var do_confirm_re_2 = new RegExp('^DELETE\\s+FROM\\s', 'i');
+        var do_confirm_re_0 = new RegExp('^\\s*DROP\\s+(IF EXISTS\\s+)?(TABLE|DATABASE|PROCEDURE)\\s', 'i');
+        var do_confirm_re_1 = new RegExp('^\\s*ALTER\\s+TABLE\\s+((`[^`]+`)|([A-Za-z0-9_$]+))\\s+DROP\\s', 'i');
+        var do_confirm_re_2 = new RegExp('^\\s*DELETE\\s+FROM\\s', 'i');
         if (do_confirm_re_0.test(sqlQuery1.value)
             || do_confirm_re_1.test(sqlQuery1.value)
             || do_confirm_re_2.test(sqlQuery1.value)) {
             var message      = (sqlQuery1.value.length > 100)
                              ? sqlQuery1.value.substr(0, 100) + '\n    ...'
                              : sqlQuery1.value;
-            var is_confirmed = confirm(confirmMsg + ' :\n' + message);
+            var is_confirmed = confirm(PMA_messages['strDoYouReally'] + ' :\n' + message);
             // drop/delete/alter statement is confirmed -> update the
             // "is_js_confirmed" form field so the confirm test won't be
             // run on the server side and allows to submit the form
@@ -185,6 +190,28 @@ function confirmQuery(theForm1, sqlQuery1)
 } // end of the 'confirmQuery()' function
 
 
+/**
+ * Displays a confirmation box before disabling the BLOB repository for a given database.
+ * This function is called while clicking links
+ *
+ * @param   object   the database 
+ *
+ * @return  boolean  whether to disable the repository or not
+ */
+function confirmDisableRepository(theDB)
+{
+    // Confirmation is not required in the configuration file
+    // or browser is Opera (crappy js implementation)
+    if (PMA_messages['strDoYouReally'] == '' || typeof(window.opera) != 'undefined') {
+        return true;
+    }
+
+    var is_confirmed = confirm(PMA_messages['strBLOBRepositoryDisableStrongWarning'] + '\n' + PMA_messages['strBLOBRepositoryDisableAreYouSure']);
+
+    return is_confirmed;
+} // end of the 'confirmDisableBLOBRepository()' function
+
+
 /**
  * Displays an error message if the user submitted the sql query form with no
  * sql query, else checks for "DROP/DELETE/ALTER" statements
@@ -244,7 +271,7 @@ function checkSqlQuery(theForm)
 
     if (isEmpty) {
         sqlQuery.select();
-        alert(errorMsg0);
+        alert(PMA_messages['strFormEmpty']);
         sqlQuery.focus();
         return false;
     }
@@ -297,7 +324,7 @@ function emptyFormElements(theForm, theFieldName)
     if (isEmpty) {
         theForm.reset();
         theField.select();
-        alert(errorMsg0);
+        alert(PMA_messages['strFormEmpty']);
         theField.focus();
         return false;
     }
@@ -331,7 +358,7 @@ function checkFormElementInRange(theForm, theFieldName, message, min, max)
     // It's not a number
     if (isNaN(val)) {
         theField.select();
-        alert(errorMsg1);
+        alert(PMA_messages['strNotNumber']);
         theField.focus();
         return false;
     }
@@ -363,13 +390,13 @@ function checkTableEditForm(theForm, fieldsCnt)
     {
         id = "field_" + i + "_2";
         elm = getElement(id);
-        if (elm.value == 'VARCHAR' || elm.value == 'CHAR') {
+        if (elm.value == 'VARCHAR' || elm.value == 'CHAR' || elm.value == 'BIT') {
             elm2 = getElement("field_" + i + "_3");
             val = parseInt(elm2.value);
             elm3 = getElement("field_" + i + "_1");
             if (isNaN(val) && elm3.value != "") {
                 elm2.select();
-                alert(errorMsg1);
+                alert(PMA_messages['strNotNumber']);
                 elm2.focus();
                 return false;
             }
@@ -384,7 +411,7 @@ function checkTableEditForm(theForm, fieldsCnt)
     }
     if (atLeastOneField == 0) {
         var theField = theForm.elements["field_0_1"];
-        alert(errorMsg0);
+        alert(PMA_messages['strFormEmpty']);
         theField.focus();
         return false;
     }
@@ -988,8 +1015,8 @@ function getElement(e,f){
         if(f.document.layers[e]) {
             return f.document.layers[e];
         }
-        for(W=0;i<f.document.layers.length;W++) {
-            return(getElement(e,fdocument.layers[W]));
+        for(W=0;W<f.document.layers.length;W++) {
+            return(getElement(e,f.document.layers[W]));
         }
     }
     if(document.all) {
@@ -1212,3 +1239,68 @@ function pdfPaperSize(format, axis) {
 
     return 0;
 }
+
+/**
+ * rajk - for playing media from the BLOB repository
+ *
+ * @param   var     
+ * @param   var     url_params  main purpose is to pass the token 
+ * @param   var     bs_ref      BLOB repository reference
+ * @param   var     m_type      type of BLOB repository media
+ * @param   var     w_width     width of popup window
+ * @param   var     w_height    height of popup window
+ */
+function popupBSMedia(url_params, bs_ref, m_type, is_cust_type, w_width, w_height)
+{
+    // if width not specified, use default
+    if (w_width == undefined)
+        w_width = 640;
+
+    // if height not specified, use default
+    if (w_height == undefined)
+        w_height = 480;
+
+    // open popup window (for displaying video/playing audio)
+    var mediaWin = window.open('bs_play_media.php?' + url_params + '&bs_reference=' + bs_ref + '&media_type=' + m_type + '&custom_type=' + is_cust_type, 'viewBSMedia', 'width=' + w_width + ', height=' + w_height + ', resizable=1, scrollbars=1, status=0');
+}
+
+/**
+ * rajk - popups a request for changing MIME types for files in the BLOB repository
+ *
+ * @param   var     db                      database name
+ * @param   var     table                   table name
+ * @param   var     reference               BLOB repository reference
+ * @param   var     current_mime_type       current MIME type associated with BLOB repository reference
+ */
+function requestMIMETypeChange(db, table, reference, current_mime_type)
+{
+    // no mime type specified, set to default (nothing)
+    if (undefined == current_mime_type)
+        current_mime_type == "";
+
+    // prompt user for new mime type
+    var new_mime_type = prompt("Enter custom MIME type", current_mime_type);
+
+    // if new mime_type is specified and is not the same as the previous type, request for mime type change
+    if (new_mime_type && new_mime_type != current_mime_type)
+        changeMIMEType(db, table, reference, new_mime_type);
+}
+
+/**
+ * rajk - changes MIME types for files in the BLOB repository
+ *
+ * @param   var     db              database name
+ * @param   var     table           table name
+ * @param   var     reference       BLOB repository reference
+ * @param   var     mime_type       new MIME type to be associated with BLOB repository reference
+ */
+function changeMIMEType(db, table, reference, mime_type)
+{
+    // specify url and parameters for mootools AJAx request
+    var mime_chg_url = 'bs_change_mime_type.php';
+    var params = { bs_db: db, bs_table: table, bs_reference: reference, bs_new_mime_type: mime_type };
+
+    // create AJAX object with above options and execute request
+    var chgRequest = new Request({ method: 'post', url: mime_chg_url, data: params, evalScripts: true });
+    chgRequest.send();
+}
