@@ -1,6 +1,10 @@
 <?php
-/* $Id: Config.class.php 9717 2006-11-17 10:05:59Z nijel $ */
-// vim: expandtab sw=4 ts=4 sts=4:
+/* vim: set expandtab sw=4 ts=4 sts=4: */
+/**
+ *
+ *
+ * @version $Id: Config.class.php 12197 2009-01-19 17:32:29Z lem9 $
+ */
 
 /**
  * Configuration class
@@ -28,6 +32,7 @@ class PMA_Config
      */
     var $source_mtime = 0;
     var $default_source_mtime = 0;
+    var $set_mtime = 0;
 
     /**
      * @var boolean
@@ -50,7 +55,7 @@ class PMA_Config
     var $default_server = array();
 
     /**
-     * @var boolean wether init is done or mot
+     * @var boolean whether init is done or not
      * set this to false to force some initial checks
      * like checking for required functions
      */
@@ -69,7 +74,7 @@ class PMA_Config
         // PMA_Config::load()
         $this->load($source);
 
-        // other settings, independant from config file, comes in
+        // other settings, independent from config file, comes in
         $this->checkSystem();
 
         $this->checkIsHttps();
@@ -80,7 +85,7 @@ class PMA_Config
      */
     function checkSystem()
     {
-        $this->set('PMA_VERSION', '2.9.1.1');
+        $this->set('PMA_VERSION', '3.1.2');
         /**
          * @deprecated
          */
@@ -101,7 +106,7 @@ class PMA_Config
     }
 
     /**
-     * wether to use gzip output compression or not
+     * whether to use gzip output compression or not
      */
     function checkOutputCompression()
     {
@@ -163,7 +168,6 @@ class PMA_Config
         } elseif (preg_match('@OmniWeb/([0-9].[0-9]{1,2})@', $HTTP_USER_AGENT, $log_version)) {
             $this->set('PMA_USR_BROWSER_VER', $log_version[1]);
             $this->set('PMA_USR_BROWSER_AGENT', 'OMNIWEB');
-        //} elseif (ereg('Konqueror/([0-9].[0-9]{1,2})', $HTTP_USER_AGENT, $log_version)) {
         // Konqueror 2.2.2 says Konqueror/2.2.2
         // Konqueror 3.0.3 says Konqueror/3
         } elseif (preg_match('@(Konqueror/)(.*)(;)@', $HTTP_USER_AGENT, $log_version)) {
@@ -173,6 +177,9 @@ class PMA_Config
                    && preg_match('@Safari/([0-9]*)@', $HTTP_USER_AGENT, $log_version2)) {
             $this->set('PMA_USR_BROWSER_VER', $log_version[1] . '.' . $log_version2[1]);
             $this->set('PMA_USR_BROWSER_AGENT', 'SAFARI');
+        } elseif (preg_match('@rv:1.9(.*)Gecko@', $HTTP_USER_AGENT)) {
+            $this->set('PMA_USR_BROWSER_VER', '1.9');
+            $this->set('PMA_USR_BROWSER_AGENT', 'GECKO');
         } elseif (preg_match('@Mozilla/([0-9].[0-9]{1,2})@', $HTTP_USER_AGENT, $log_version)) {
             $this->set('PMA_USR_BROWSER_VER', $log_version[1]);
             $this->set('PMA_USR_BROWSER_AGENT', 'MOZILLA');
@@ -192,9 +199,6 @@ class PMA_Config
         } elseif ($this->get('GD2Available') == 'no') {
             $this->set('PMA_IS_GD2', 0);
         } else {
-            if (!@extension_loaded('gd')) {
-                PMA_dl('gd');
-            }
             if (!@function_exists('imagecreatetruecolor')) {
                 $this->set('PMA_IS_GD2', 0);
             } else {
@@ -206,7 +210,7 @@ class PMA_Config
                         $this->set('PMA_IS_GD2', 0);
                     }
                 } else {
-                    /* We must do hard way... */
+                    /* We must do hard way... but almost no chance to execute this */
                     ob_start();
                     phpinfo(INFO_MODULES); /* Only modules */
                     $a = strip_tags(ob_get_contents());
@@ -251,7 +255,7 @@ class PMA_Config
         $this->set('PMA_IS_WINDOWS', 0);
         // If PHP_OS is defined then continue
         if (defined('PHP_OS')) {
-            if (stristr(PHP_OS, 'win') ) {
+            if (stristr(PHP_OS, 'win')) {
                 // Is it some version of Windows
                 $this->set('PMA_IS_WINDOWS', 1);
             } elseif (stristr(PHP_OS, 'OS/2')) {
@@ -384,7 +388,26 @@ class PMA_Config
         }
 
         /**
-         * @TODO check validity of $_COOKIE['pma_collation_connection']
+         * Backward compatibility code
+         */
+        if (!empty($cfg['DefaultTabTable'])) {
+            $cfg['DefaultTabTable'] = str_replace('_properties', '', str_replace('tbl_properties.php', 'tbl_sql.php', $cfg['DefaultTabTable']));
+        }
+        if (!empty($cfg['DefaultTabDatabase'])) {
+            $cfg['DefaultTabDatabase'] = str_replace('_details', '', str_replace('db_details.php', 'db_sql.php', $cfg['DefaultTabDatabase']));
+        }
+
+        $this->checkFontsize();
+        //$this->checkPmaAbsoluteUri();
+        $this->settings = PMA_array_merge_recursive($this->settings, $cfg);
+
+        // Handling of the collation must be done after merging of $cfg
+        // (from config.inc.php) so that $cfg['DefaultConnectionCollation']
+        // can have an effect. Note that the presence of collation
+        // information in a cookie has priority over what is defined
+        // in the default or user's config files.
+        /**
+         * @todo check validity of $_COOKIE['pma_collation_connection']
          */
         if (! empty($_COOKIE['pma_collation_connection'])) {
             $this->set('collation_connection',
@@ -393,11 +416,13 @@ class PMA_Config
             $this->set('collation_connection',
                 $this->get('DefaultConnectionCollation'));
         }
-
+        // Now, a collation information could come from REQUEST
+        // (an example of this: the collation selector in main.php)
+        // so the following handles the setting of collation_connection
+        // and later, in common.inc.php, the cookie will be set
+        // according to this.
         $this->checkCollationConnection();
-        $this->checkFontsize();
-        //$this->checkPmaAbsoluteUri();
-        $this->settings = PMA_array_merge_recursive($this->settings, $cfg);
+
         return true;
     }
 
@@ -424,7 +449,7 @@ class PMA_Config
     /**
      * check config source
      *
-     * @return  boolean wether source is valid or not
+     * @return  boolean whether source is valid or not
      */
     function checkConfigSource()
     {
@@ -451,13 +476,15 @@ class PMA_Config
         }
 
         // Check for permissions (on platforms that support it):
-        $perms = @fileperms($this->getSource());
-        if (!($perms === false) && ($perms & 2)) {
-            // This check is normally done after loading configuration
-            $this->checkWebServerOs();
-            if ($this->get('PMA_IS_WINDOWS') == 0) {
-                $this->source_mtime = 0;
-                die('Wrong permissions on configuration file, should not be world writable!');
+        if ($this->get('CheckConfigurationPermissions')) {
+            $perms = @fileperms($this->getSource());
+            if (!($perms === false) && ($perms & 2)) {
+                // This check is normally done after loading configuration
+                $this->checkWebServerOs();
+                if ($this->get('PMA_IS_WINDOWS') == 0) {
+                    $this->source_mtime = 0;
+                    die('Wrong permissions on configuration file, should not be world writable!');
+                }
             }
         }
 
@@ -486,7 +513,10 @@ class PMA_Config
      */
     function set($setting, $value)
     {
-        $this->settings[$setting] = $value;
+        if (!isset($this->settings[$setting]) || $this->settings[$setting] != $value) {
+            $this->settings[$setting] = $value;
+            $this->set_mtime = time();
+        }
     }
 
     /**
@@ -499,13 +529,15 @@ class PMA_Config
     }
 
     /**
-     * old PHP 4 style constructor
-     *
-     * @deprecated
+     * returns a unique value to force a CSS reload if either the config
+     * or the theme changes
+     * must also check the pma_fontsize cookie in case there is no
+     * config file
+     * @return  int  Unix timestamp
      */
-    function PMA_Config($source = null)
+    function getThemeUniqueValue()
     {
-        $this->__construct($source);
+        return intval((null !== $_SESSION['PMA_Config']->get('fontsize') ? $_SESSION['PMA_Config']->get('fontsize') : (isset($_COOKIE['pma_fontsize']) ? $_COOKIE['pma_fontsize'] : 0))) + ($this->source_mtime + $this->default_source_mtime + $_SESSION['PMA_Theme']->mtime_info + $_SESSION['PMA_Theme']->filesize_info) . (isset($_SESSION['userconf']['custom_color']) ? substr($_SESSION['userconf']['custom_color'],1,6) : '');
     }
 
     /**
@@ -515,10 +547,11 @@ class PMA_Config
      */
     function checkPmaAbsoluteUri()
     {
-        // Setup a default value to let the people and lazy syadmins work anyway,
+        // Setup a default value to let the people and lazy sysadmins work anyway,
         // they'll get an error if the autodetect code doesn't work
         $pma_absolute_uri = $this->get('PmaAbsoluteUri');
         $is_https = $this->get('is_https');
+
         if (strlen($pma_absolute_uri) < 5
             // needed to catch http/https switch
             || ($is_https && substr($pma_absolute_uri, 0, 6) != 'https:')
@@ -527,12 +560,16 @@ class PMA_Config
             $url = array();
 
             // At first we try to parse REQUEST_URI, it might contain full URL
+            /**
+             * REQUEST_URI contains PATH_INFO too, this is not what we want
+             * script-php/pathinfo/
             if (PMA_getenv('REQUEST_URI')) {
                 $url = @parse_url(PMA_getenv('REQUEST_URI')); // produces E_WARNING if it cannot get parsed, e.g. '/foobar:/'
                 if ($url === false) {
-                    $url = array( 'path' => $_SERVER['REQUEST_URI'] );
+                    $url = array('path' => $_SERVER['REQUEST_URI']);
                 }
             }
+             */
 
             // If we don't have scheme, we didn't have full URL so we need to
             // dig deeper
@@ -569,13 +606,17 @@ class PMA_Config
 
                 // And finally the path could be already set from REQUEST_URI
                 if (empty($url['path'])) {
+                    /**
+                     * REQUEST_URI contains PATH_INFO too, this is not what we want
+                     * script-php/pathinfo/
                     if (PMA_getenv('PATH_INFO')) {
                         $path = parse_url(PMA_getenv('PATH_INFO'));
                     } else {
                         // PHP_SELF in CGI often points to cgi executable, so use it
                         // as last choice
-                        $path = parse_url(PMA_getenv('PHP_SELF'));
-                    }
+                     */
+                        $path = parse_url($GLOBALS['PMA_PHP_SELF']);
+                    //}
                     $url['path'] = $path['path'];
                 }
             }
@@ -651,18 +692,15 @@ class PMA_Config
                     . $pma_absolute_uri;
             }
         }
-
         $this->set('PmaAbsoluteUri', $pma_absolute_uri);
     }
 
     /**
      * check selected collation_connection
-     * @TODO check validity of $_REQUEST['collation_connection']
+     * @todo check validity of $_REQUEST['collation_connection']
      */
     function checkCollationConnection()
     {
-        // (could be improved by executing it after the MySQL connection only if
-        //  PMA_MYSQL_INT_VERSION >= 40100)
         if (! empty($_REQUEST['collation_connection'])) {
             $this->set('collation_connection',
                 strip_tags($_REQUEST['collation_connection']));
@@ -696,11 +734,13 @@ class PMA_Config
         if (preg_match('/^[0-9.]+(px|em|pt|\%)$/', $new_fontsize)) {
             $this->set('fontsize', $new_fontsize);
         } elseif (! $this->get('fontsize')) {
-            $this->set('fontsize', '100%');
+            // 80% would correspond to the default browser font size
+            // of 16, but use 82% to help read the monoface font
+            $this->set('fontsize', '82%');
         }
 
         if (function_exists('PMA_setCookie')) {
-            PMA_setCookie('pma_fontsize', $this->get('fontsize'), '100%');
+            PMA_setCookie('pma_fontsize', $this->get('fontsize'), '82%');
         }
     }
 
@@ -708,13 +748,19 @@ class PMA_Config
      * checks if upload is enabled
      *
      */
+
     function checkUpload()
     {
-        $this->set('enable_upload', true);
-        if (strtolower(@ini_get('file_uploads')) == 'off'
-          || @ini_get('file_uploads') == 0) {
+        if (ini_get('file_uploads')) {
+            $this->set('enable_upload', true);
+            // if set "php_admin_value file_uploads Off" in httpd.conf
+            // ini_get() also returns the string "Off" in this case:
+            if ('off' == strtolower(ini_get('file_uploads'))) {
+                $this->set('enable_upload', false);
+            }
+         } else {
             $this->set('enable_upload', false);
-        }
+         }
     }
 
     /**
@@ -731,9 +777,9 @@ class PMA_Config
 
         if ($postsize = ini_get('post_max_size')) {
             $this->set('max_upload_size',
-                min(get_real_size($filesize), get_real_size($postsize)));
+                min(PMA_get_real_size($filesize), PMA_get_real_size($postsize)));
         } else {
-            $this->set('max_upload_size', get_real_size($filesize));
+            $this->set('max_upload_size', PMA_get_real_size($filesize));
         }
     }
 
@@ -748,7 +794,7 @@ class PMA_Config
     /**
      * @static
      */
-    function isHttps()
+    static public function isHttps()
     {
         $is_https = false;
 
@@ -797,7 +843,7 @@ class PMA_Config
     /**
      * @static
      */
-    function getCookiePath()
+    static public function getCookiePath()
     {
         static $cookie_path = null;
 
@@ -807,27 +853,34 @@ class PMA_Config
 
         $url = '';
 
+        /**
+         * REQUEST_URI contains PATH_INFO too, this is not what we want
+         * script-php/pathinfo/
         if (PMA_getenv('REQUEST_URI')) {
             $url = PMA_getenv('REQUEST_URI');
         }
+         */
 
         // If we don't have path
         if (empty($url)) {
-            if (PMA_getenv('PATH_INFO')) {
-                $url = PMA_getenv('PATH_INFO');
-            } elseif (PMA_getenv('PHP_SELF')) {
+            if ($GLOBALS['PMA_PHP_SELF']) {
                 // PHP_SELF in CGI often points to cgi executable, so use it
                 // as last choice
-                $url = PMA_getenv('PHP_SELF');
+                $url = $GLOBALS['PMA_PHP_SELF'];
+            // on IIS with PHP-CGI:
             } elseif (PMA_getenv('SCRIPT_NAME')) {
-                $url = PMA_getenv('PHP_SELF');
+                $url = PMA_getenv('SCRIPT_NAME');
             }
         }
 
+        /**
+         * REQUEST_URI contains PATH_INFO too, this is not what we want
+         * script-php/pathinfo/
         $parsed_url = @parse_url($_SERVER['REQUEST_URI']); // produces E_WARNING if it cannot get parsed, e.g. '/foobar:/'
         if ($parsed_url === false) {
+         */
             $parsed_url = array('path' => $url);
-        }
+        //}
 
         $cookie_path   = substr($parsed_url['path'], 0, strrpos($parsed_url['path'], '/'))  . '/';
 
@@ -839,8 +892,9 @@ class PMA_Config
      */
     function enableBc()
     {
-        $GLOBALS['cfg']             =& $this->settings;
-        $GLOBALS['default_server']  =& $this->default_server;
+        $GLOBALS['cfg']             = $this->settings;
+        $GLOBALS['default_server']  = $this->default_server;
+        unset($this->default_server);
         $GLOBALS['collation_connection'] = $this->get('collation_connection');
         $GLOBALS['is_upload']       = $this->get('enable_upload');
         $GLOBALS['max_upload_size'] = $this->get('max_upload_size');
@@ -858,7 +912,7 @@ class PMA_Config
             'PMA_IS_GD2',
             'PMA_USR_OS',
             'PMA_USR_BROWSER_VER',
-            'PMA_USR_BROWSER_AGENT',
+            'PMA_USR_BROWSER_AGENT'
             );
 
         foreach ($defines as $define) {
@@ -882,7 +936,7 @@ class PMA_Config
      * @param   string  $current_size   current selected font size with unit
      * @return  array   selectable font sizes
      */
-    function getFontsizeOptions($current_size = '100%')
+    static protected function _getFontsizeOptions($current_size = '82%')
     {
         $unit = preg_replace('/[0-9.]*/', '', $current_size);
         $value = preg_replace('/[^0-9.]*/', '', $current_size);
@@ -940,16 +994,24 @@ class PMA_Config
      *
      * @uses    $_SESSION['PMA_Config']
      * @uses    PMA_Config::get()
-     * @uses    PMA_Config::getFontsizeOptions()
+     * @uses    PMA_Config::_getFontsizeOptions()
      * @uses    $GLOBALS['strFontSize']
      * @static
      * @param   string  $current_size   currently slected font size with unit
      * @return  string  html selectbox
      */
-    function getFontsizeSelection()
+    static protected function _getFontsizeSelection()
     {
         $current_size = $_SESSION['PMA_Config']->get('fontsize');
-        $options = PMA_Config::getFontsizeOptions($current_size);
+        // for the case when there is no config file (this is supported)
+        if (empty($current_size)) {
+            if (isset($_COOKIE['pma_fontsize'])) {
+                $current_size = $_COOKIE['pma_fontsize'];
+            } else {
+                $current_size = '82%';
+            }
+        }
+        $options = PMA_Config::_getFontsizeOptions($current_size);
 
         $return = '<label for="select_fontsize">' . $GLOBALS['strFontSize'] . ':</label>' . "\n";
         $return .= '<select name="fontsize" id="select_fontsize" onchange="this.form.submit();">' . "\n";
@@ -969,18 +1031,18 @@ class PMA_Config
      * return complete font size selection form
      *
      * @uses    PMA_generate_common_hidden_inputs()
-     * @uses    PMA_Config::getFontsizeSelection()
+     * @uses    PMA_Config::_getFontsizeSelection()
      * @uses    $GLOBALS['strGo']
      * @static
      * @param   string  $current_size   currently slected font size with unit
      * @return  string  html selectbox
      */
-    function getFontsizeForm()
+    static public function getFontsizeForm()
     {
         return '<form name="form_fontsize_selection" id="form_fontsize_selection"'
             . ' method="post" action="index.php" target="_parent">' . "\n"
             . PMA_generate_common_hidden_inputs() . "\n"
-            . PMA_Config::getFontsizeSelection() . "\n"
+            . PMA_Config::_getFontsizeSelection() . "\n"
             . '<noscript>' . "\n"
             . '<input type="submit" value="' . $GLOBALS['strGo'] . '" />' . "\n"
             . '</noscript>' . "\n"
