@@ -1,9 +1,7 @@
 <?php
-/* $Id: sqlparser.data.php 9284 2006-08-12 19:14:48Z lem9 $ */
-// vim: expandtab sw=4 ts=4 sts=4:
-
-
-/** SQL Parser Matching Data
+/* vim: set expandtab sw=4 ts=4 sts=4: */
+/**
+ * SQL Parser Matching Data
  *
  * Copyright 2002 Robin Johnson <robbat2@users.sourceforge.net>
  * http://www.orbis-terrarum.net/?l=people.robbat2
@@ -15,13 +13,21 @@
  *
  * Note: before adding a value in the arrays, ensure that you respect
  * proper sorting, especially with underscores. And don't forget to
- * update the _cnt variable at the end of each array. 
+ * update the _cnt variable at the end of each array.
  * (It's slower to have PHP do the count).
  *
  * It's easier to use only uppercase for proper sorting. In case of
- * doubt, use the DEBUG code after this function's definition. 
+ * doubt, use the DEBUG code after this function's definition.
+ *
+ * @version$Id: sqlparser.data.php 11345 2008-06-24 17:51:49Z lem9 $
  */
+if (! defined('PHPMYADMIN')) {
+    exit;
+}
 
+/**
+ * @global array MySQL function names
+ */
 $PMA_SQPdata_function_name = array (
     'ABS',
     'ACOS',
@@ -29,12 +35,18 @@ $PMA_SQPdata_function_name = array (
     'ADDTIME',
     'AES_DECRYPT',
     'AES_ENCRYPT',
-    'AREA',                     // polygon-property-functions.html
+    'AREA',                     // Area() polygon-property-functions.html
+    'ASBINARY',                 // AsBinary()
     'ASCII',
     'ASIN',
+    'ASTEXT',                   // AsText()
     'ATAN',
     'ATAN2',
     'AVG',
+    'BDMPOLYFROMTEXT',          // BdMPolyFromText()
+    'BDMPOLYFROMWKB',           // BdMPolyFromWKB()
+    'BDPOLYFROMTEXT',           // BdPolyFromText()
+    'BDPOLYFROMWKB',            // BdPolyFromWKB()
     'BENCHMARK',
     'BIN',
     'BIT_AND',
@@ -42,11 +54,12 @@ $PMA_SQPdata_function_name = array (
     'BIT_LENGTH',
     'BIT_OR',
     'BIT_XOR',                  // group-by-functions.html
-    'Boundary',                 // general-geometry-property-functions.html
+    'BOUNDARY',                 // Boundary() general-geometry-property-functions.html
+    'BUFFER',                   // Buffer()
     'CAST',
     'CEIL',
     'CEILING',
-    'CENTROID',                 // multipolygon-property-functions.html
+    'CENTROID',                 // Centroid() multipolygon-property-functions.html
     'CHAR',                     // string-functions.html
     'CHARACTER_LENGTH',
     'CHARSET',                  // information-functions.html
@@ -58,13 +71,16 @@ $PMA_SQPdata_function_name = array (
     'CONCAT',
     'CONCAT_WS',
     'CONNECTION_ID',
+    'CONTAINS',                 // Contains()
     'CONV',
     'CONVERT',
     'CONVERT_TZ',
+    'CONVEXHULL',               // ConvexHull()
     'COS',
     'COT',
     'COUNT',
     'CRC32',                    // mathematical-functions.html
+    'CROSSES',                  // Crosses()
     'CURDATE',
     'CURRENT_DATE',
     'CURRENT_TIME',
@@ -88,16 +104,21 @@ $PMA_SQPdata_function_name = array (
     'DEGREES',
     'DES_DECRYPT',
     'DES_ENCRYPT',
-    'DIMENSION',                // general-geometry-property-functions.html
+    'DIFFERENCE',               // Difference()
+    'DIMENSION',                // Dimension() general-geometry-property-functions.html
+    'DISJOINT',                 // Disjoint()
+    'DISTANCE',                 // Distance()
     'ELT',
     'ENCODE',
     'ENCRYPT',
-    'ENDPOINT',                 // linestring-property-functions.html
-    'ENVELOPE',                 // general-geometry-property-functions.html
+    'ENDPOINT',                 // EndPoint() linestring-property-functions.html
+    'ENVELOPE',                 // Envelope() general-geometry-property-functions.html
+    'EQUALS',                   // Equals()
     'EXP',
     'EXPORT_SET',
-    'EXTERIORRING',             // polygon-property-functions.html
+    'EXTERIORRING',             // ExteriorRing() polygon-property-functions.html
     'EXTRACT',
+    'EXTRACTVALUE',             // ExtractValue() xml-functions.html
     'FIELD',
     'FIND_IN_SET',
     'FLOOR',
@@ -105,11 +126,20 @@ $PMA_SQPdata_function_name = array (
     'FOUND_ROWS',
     'FROM_DAYS',
     'FROM_UNIXTIME',
-    'GEOMETRYN',                // geometrycollection-property-functions.html
-    'GEOMETRYTYPE',             // general-geometry-property-functions.html
+    'GEOMCOLLFROMTEXT',         // GeomCollFromText()
+    'GEOMCOLLFROMWKB',          // GeomCollFromWKB()
+    'GEOMETRYCOLLECTION',       // GeometryCollection()
+    'GEOMETRYCOLLECTIONFROMTEXT',   // GeometryCollectionFromText()
+    'GEOMETRYCOLLECTIONFROMWKB',    // GeometryCollectionFromWKB()
+    'GEOMETRYFROMTEXT',         // GeometryFromText()
+    'GEOMETRYFROMWKB',          // GeometryFromWKB()
+    'GEOMETRYN',                // GeometryN() geometrycollection-property-functions.html
+    'GEOMETRYTYPE',             // GeometryType() general-geometry-property-functions.html
+    'GEOMFROMTEXT',             // GeomFromText()
+    'GEOMFROMWKB',              // GeomFromWKB()
     'GET_FORMAT',
     'GET_LOCK',
-    'GLENGTH',                  // linestring-property-functions.html
+    'GLENGTH',                  // GLength() linestring-property-functions.html
     'GREATEST',
     'GROUP_CONCAT',
     'GROUP_UNIQUE_USERS',
@@ -121,13 +151,15 @@ $PMA_SQPdata_function_name = array (
     'INET_NTOA',
     'INSERT',                   // string-functions.html
     'INSTR',
-    'INTERIORRINGN',            // polygon-property-functions.html
+    'INTERIORRINGN',            // InteriorRingN() polygon-property-functions.html
+    'INTERSECTION',             // Intersection()
+    'INTERSECTS',               // Intersects()
     'INTERVAL',
-    'ISCLOSED',                 // multilinestring-property-functions.html
-    'ISEMPTY',                  // general-geometry-property-functions.html
+    'ISCLOSED',                 // IsClosed() multilinestring-property-functions.html
+    'ISEMPTY',                  // IsEmpty() general-geometry-property-functions.html
     'ISNULL',
-    'ISRING',                   // linestring-property-functions.html
-    'ISSIMPLE',                 // general-geometry-property-functions.html
+    'ISRING',                   // IsRing() linestring-property-functions.html
+    'ISSIMPLE',                 // IsSimple() general-geometry-property-functions.html
     'IS_FREE_LOCK',
     'IS_USED_LOCK',             // miscellaneous-functions.html
     'LAST_DAY',
@@ -136,6 +168,11 @@ $PMA_SQPdata_function_name = array (
     'LEAST',
     'LEFT',
     'LENGTH',
+    'LINEFROMTEXT',             // LineFromText()
+    'LINEFROMWKB',              // LineFromWKB()
+    'LINESTRING',               // LineString()
+    'LINESTRINGFROMTEXT',       // LineStringFromText()
+    'LINESTRINGFROMWKB',        // LineStringFromWKB()
     'LN',
     'LOAD_FILE',
     'LOCALTIME',
@@ -152,29 +189,62 @@ $PMA_SQPdata_function_name = array (
     'MAKE_SET',
     'MASTER_POS_WAIT',
     'MAX',
+    'MBRCONTAINS',              // MBRContains()
+    'MBRDISJOINT',              // MBRDisjoint()
+    'MBREQUAL',                 // MBREqual()
+    'MBRINTERSECTS',            // MBRIntersects()
+    'MBROVERLAPS',              // MBROverlaps()
+    'MBRTOUCHES',               // MBRTouches()
+    'MBRWITHIN',                // MBRWithin()
     'MD5',
     'MICROSECOND',
     'MID',
     'MIN',
     'MINUTE',
+    'MLINEFROMTEXT',            // MLineFromText()
+    'MLINEFROMWKB',             // MLineFromWKB()
     'MOD',
     'MONTH',
     'MONTHNAME',
     'NOW',
+    'MPOINTFROMTEXT',           // MPointFromText()
+    'MPOINTFROMWKB',            // MPointFromWKB()
+    'MPOLYFROMTEXT',            // MPolyFromText()
+    'MPOLYFROMWKB',             // MPolyFromWKB()
+    'MULTILINESTRING',          // MultiLineString()
+    'MULTILINESTRINGFROMTEXT',  // MultiLineStringFromText()
+    'MULTILINESTRINGFROMWKB',   // MultiLineStringFromWKB()
+    'MULTIPOINT',               // MultiPoint()
+    'MULTIPOINTFROMTEXT',       // MultiPointFromText()
+    'MULTIPOINTFROMWKB',        // MultiPointFromWKB()
+    'MULTIPOLYGON',             // MultiPolygon()
+    'MULTIPOLYGONFROMTEXT',     // MultiPolygonFromText()
+    'MULTIPOLYGONFROMWKB',      // MultiPolygonFromWKB()
+    'NAME_CONST',               // NAME_CONST()
+    'NOW',                      // NOW()
     'NULLIF',
-    'NUMGEOMETRIES',            // geometrycollection-property-functions.html
-    'NUMINTERIORRINGS',         // polygon-property-functions.html
-    'NUMPOINTS',                // linestring-property-functions.html
+    'NUMGEOMETRIES',            // NumGeometries() geometrycollection-property-functions.html
+    'NUMINTERIORRINGS',         // NumInteriorRings() polygon-property-functions.html
+    'NUMPOINTS',                // NumPoints() linestring-property-functions.html
     'OCT',
     'OCTET_LENGTH',
     'OLD_PASSWORD',
     'ORD',
+    'OVERLAPS',                 // Overlaps()
     'PASSWORD',
     'PERIOD_ADD',
     'PERIOD_DIFF',
     'PI',
-    'POINTN',                   // linestring-property-functions.html
-    'POINTONSURFACE',           // multipolygon-property-functions.html
+    'POINT',                    // Point()
+    'POINTFROMTEXT',            // PointFromText()
+    'POINTFROMWKB',             // PointFromWKB()
+    'POINTN',                   // PointN() inestring-property-functions.html
+    'POINTONSURFACE',           // PointOnSurface() multipolygon-property-functions.html
+    'POLYFROMTEXT',             // PolyFromText()
+    'POLYFROMWKB',              // PolyFromWKB()
+    'POLYGON',                  // Polygon()
+    'POLYGONFROMTEXT',          // PolygonFromText()
+    'POLYGONFROMWKB',           // PolygonFromWKB()
     'POSITION',
     'POW',
     'POWER',
@@ -182,6 +252,7 @@ $PMA_SQPdata_function_name = array (
     'QUOTE',
     'RADIANS',
     'RAND',
+    'RELATED',                  // Related()
     'RELEASE_LOCK',
     'REPEAT',
     'REPLACE',                  // string-functions.html
@@ -204,7 +275,7 @@ $PMA_SQPdata_function_name = array (
     'SPACE',
     'SQRT',
     'SRID',                     // general-geometry-property-functions.html
-    'STARTPOINT',               // linestring-property-functions.html
+    'STARTPOINT',               // StartPoint() linestring-property-functions.html
     'STD',
     'STDDEV',
     'STDDEV_POP',               // group-by-functions.html
@@ -212,10 +283,12 @@ $PMA_SQPdata_function_name = array (
     'STRCMP',
     'STR_TO_DATE',
     'SUBDATE',
+    'SUBSTR',
     'SUBSTRING',
     'SUBSTRING_INDEX',
     'SUBTIME',
     'SUM',
+    'SYMDIFFERENCE',            // SymDifference()
     'SYSDATE',
     'SYSTEM_USER',
     'TAN',
@@ -226,6 +299,7 @@ $PMA_SQPdata_function_name = array (
     'TIMESTAMPDIFF',
     'TIME_FORMAT',
     'TIME_TO_SEC',
+    'TOUCHES',                  // Touches()
     'TO_DAYS',
     'TRIM',
     'TRUNCATE',                 // mathematical-functions.html
@@ -235,6 +309,7 @@ $PMA_SQPdata_function_name = array (
     'UNHEX',                    // string-functions.html
     'UNIQUE_USERS',
     'UNIX_TIMESTAMP',
+    'UPDATEXML',                // UpdateXML() xml-functions.html
     'UPPER',
     'USER',
     'UTC_DATE',
@@ -248,23 +323,33 @@ $PMA_SQPdata_function_name = array (
     'WEEK',
     'WEEKDAY',
     'WEEKOFYEAR',
+    'WITHIN',                   // Within()
     'X',                        // point-property-functions.html
     'Y',                        // point-property-functions.html
     'YEAR',
     'YEARWEEK'
 );
-//$PMA_SQPdata_function_name_cnt = count($PMA_SQPdata_function_name);
-$PMA_SQPdata_function_name_cnt = 229;
-// DEBUG
-//$test_PMA_SQPdata_function_name = $PMA_SQPdata_function_name;
-//sort($PMA_SQPdata_function_name);
-//if ($PMA_SQPdata_function_name != $test_PMA_SQPdata_function_name) {
-//    echo 'sort properly like this<pre>';
-//    print_r($PMA_SQPdata_function_name);
-//    echo '</pre>';
-//}
+/**
+ * $PMA_SQPdata_function_name_cnt = count($PMA_SQPdata_function_name);
+ *
+ * @global integer MySQL attributes count
+ */
+$PMA_SQPdata_function_name_cnt = 299;
 
+/*
+ * DEBUG
+$test_PMA_SQPdata_function_name = $PMA_SQPdata_function_name;
+sort($PMA_SQPdata_function_name);
+if ($PMA_SQPdata_function_name != $test_PMA_SQPdata_function_name) {
+    echo 'sort properly like this<pre>';
+    print_r($PMA_SQPdata_function_name);
+    echo '</pre>';
+}
+ */
 
+/**
+ * @global array MySQL attributes
+ */
 $PMA_SQPdata_column_attrib = array (
     'ARCHIVE',          // Engine
     'ASCII',
@@ -281,6 +366,7 @@ $PMA_SQPdata_column_attrib = array (
     'INNOBASE',         // Engine alias InnoDB
     'INNODB',           // Engine InnoDB
     'ISAM',             // Engine
+    'MARIA',            // Engine
     'MEMORY',           // Engine alias HEAP, but preferred
     'MERGE',            // Engine
     'MRG_ISAM',         // Engine
@@ -296,10 +382,22 @@ $PMA_SQPdata_column_attrib = array (
     'VARYING',
     'ZEROFILL'
 );
-//$PMA_SQPdata_column_attrib_cnt = count($PMA_SQPdata_column_attrib);
-$PMA_SQPdata_column_attrib_cnt = 29;
+/**
+ * $PMA_SQPdata_column_attrib_cnt = count($PMA_SQPdata_column_attrib);
+ *
+ * @global integer MySQL attributes count
+ */
+$PMA_SQPdata_column_attrib_cnt = 30;
 
+/**
+ * words that are reserved by MySQL and may not be used as identifiers without quotes
+ *
+ * @see http://dev.mysql.com/doc/refman/5.1/en/reserved-words.html
+ *
+ * @global array MySQL reserved words
+ */
 $PMA_SQPdata_reserved_word = array (
+    'ACCESSIBLE',       // 5.1
     'ACTION',
     'ADD',
     'AFTER',
@@ -329,7 +427,6 @@ $PMA_SQPdata_reserved_word = array (
     'CHARSET',
     'CHECK',
     'CHECKSUM',
-    'CLIENT',
     'COLLATE',
     'COLLATION',
     'COLUMN',
@@ -340,6 +437,7 @@ $PMA_SQPdata_reserved_word = array (
     'COMPRESSED',
     'CONCURRENT',
     'CONSTRAINT',
+    'CONTAINS',
     'CONVERT',
     'CREATE',
     'CROSS',
@@ -357,12 +455,14 @@ $PMA_SQPdata_reserved_word = array (
     'DELETE',
     'DESC',
     'DESCRIBE',
+    'DETERMINISTIC',
     'DISTINCT',
     'DISTINCTROW',
     'DIV',
     'DO',
     'DROP',
     'DUMPFILE',
+    'DUPLICATE',
     'DYNAMIC',
     'ELSE',
     'ENCLOSED',
@@ -427,6 +527,7 @@ $PMA_SQPdata_reserved_word = array (
     'LEVEL',
     'LIKE',
     'LIMIT',
+    'LINEAR',               // 5.1
     'LINES',
     'LOAD',
     'LOCAL',
@@ -434,6 +535,7 @@ $PMA_SQPdata_reserved_word = array (
     'LOCKS',
     'LOGS',
     'LOW_PRIORITY',
+    'MARIA',                // 5.1 ?
     'MASTER',
     'MASTER_CONNECT_RETRY',
     'MASTER_HOST',
@@ -450,9 +552,9 @@ $PMA_SQPdata_reserved_word = array (
     'MAX_USER_CONNECTIONS',
     'MEDIUM',
     'MERGE',
-    'MIN_ROWS',
     'MINUTE',
     'MINUTE_SECOND',
+    'MIN_ROWS',
     'MODE',
     'MODIFY',
     'MONTH',
@@ -475,7 +577,10 @@ $PMA_SQPdata_reserved_word = array (
     'OUTER',
     'OUTFILE',
     'PACK_KEYS',
+    'PAGE',                 // 5.1-maria ?
     'PARTIAL',
+    'PARTITION',            // 5.1
+    'PARTITIONS',           // 5.1
     'PASSWORD',
     'PRIMARY',
     'PRIVILEGES',
@@ -488,7 +593,10 @@ $PMA_SQPdata_reserved_word = array (
     'RAID_CHUNKS',
     'RAID_CHUNKSIZE',
     'RAID_TYPE',
+    'RANGE',                // 5.1
     'READ',
+    'READ_ONLY',            // 5.1
+    'READ_WRITE',           // 5.1
     'REFERENCES',
     'REGEXP',
     'RELOAD',
@@ -507,9 +615,10 @@ $PMA_SQPdata_reserved_word = array (
     'RLIKE',
     'ROLLBACK',
     'ROW',
-    'ROW_FORMAT',
     'ROWS',
+    'ROW_FORMAT',
     'SECOND',
+    'SECURITY',
     'SELECT',
     'SEPARATOR',
     'SERIALIZABLE',
@@ -520,6 +629,7 @@ $PMA_SQPdata_reserved_word = array (
     'SLAVE',
     'SONAME',
     'SOUNDS',                   // string-functions.html
+    'SQL',
     'SQL_AUTO_IS_NULL',
     'SQL_BIG_RESULT',
     'SQL_BIG_SELECTS',
@@ -555,6 +665,7 @@ $PMA_SQPdata_reserved_word = array (
     'THEN',
     'TO',
     'TRAILING',
+    'TRANSACTIONAL',    // 5.1 ?
     'TRUNCATE',
     'TYPE',
     'TYPES',
@@ -577,12 +688,38 @@ $PMA_SQPdata_reserved_word = array (
     'XOR',
     'YEAR_MONTH'
 );
-//$PMA_SQPdata_reserved_word_cnt = count($PMA_SQPdata_reserved_word);
-$PMA_SQPdata_reserved_word_cnt = 274;
+/**
+ * $PMA_SQPdata_reserved_word_cnt = count($PMA_SQPdata_reserved_word);
+ *
+ * @global integer MySQL reserved words count
+ */
+$PMA_SQPdata_reserved_word_cnt = 288;
+/**
+ * The previous array must be sorted so that the binary search work. 
+ * Sometimes a word is not added in the correct order, so
+ * this debugging code shows the problem. The same should be
+ * done for all arrays.
+ */
+/*
+$original = $PMA_SQPdata_reserved_word;
+sort($PMA_SQPdata_reserved_word);
+$difference = array_diff_assoc($original, $PMA_SQPdata_reserved_word);
+echo '<pre>';
+print_r($difference);
+echo '</pre>';
+echo '<pre>';
+print_r($PMA_SQPdata_reserved_word);
+echo '</pre>';
+*/
 
-// words forbidden to be used as column or table name,
-// as seen in http://dev.mysql.com/doc/mysql/en/reserved-words.html
+/**
+ * words forbidden to be used as column or table name wihtout quotes
+ * as seen in http://dev.mysql.com/doc/mysql/en/reserved-words.html
+ *
+ * @global array MySQL forbidden words
+ */
 $PMA_SQPdata_forbidden_word = array (
+    'ACCESSIBLE',       // 5.1
     'ACTION',
     'ADD',
     'AFTER',
@@ -632,7 +769,6 @@ $PMA_SQPdata_forbidden_word = array (
     'CHECK',
     'CHECKSUM',
     'CIPHER',
-    'CLIENT',
     'CLOSE',
     'COLLATE',
     'COLLATION',
@@ -796,6 +932,7 @@ $PMA_SQPdata_forbidden_word = array (
     'LEVEL',
     'LIKE',
     'LIMIT',
+    'LINEAR',               // 5.1
     'LINES',
     'LINESTRING',
     'LOAD',
@@ -903,7 +1040,10 @@ $PMA_SQPdata_forbidden_word = array (
     'RAID_CHUNKS',
     'RAID_CHUNKSIZE',
     'RAID_TYPE',
+    'RANGE',                // 5.1
     'READ',
+    'READ_ONLY',            // 5.1
+    'READ_WRITE',           // 5.1
     'READS',
     'REAL',
     'RECOVER',
@@ -1063,16 +1203,28 @@ $PMA_SQPdata_forbidden_word = array (
     'YEAR_MONTH',
     'ZEROFILL'
 );
-// echo count($PMA_SQPdata_forbidden_word);
-$PMA_SQPdata_forbidden_word_cnt = 479;
+/**
+ * count($PMA_SQPdata_forbidden_word);
+ *
+ * @global integer MySQL forbidden words count
+ */
+$PMA_SQPdata_forbidden_word_cnt = 483;
 
+/**
+ * the MySQL column/data types
+ *
+ * @see http://dev.mysql.com/doc/refman/5.1/en/data-types.html
+ * @see http://dev.mysql.com/doc/refman/5.1/en/mysql-spatial-datatypes.html
+ *
+ * @global array MySQL column types
+ */
 $PMA_SQPdata_column_type = array (
     'BIGINT',
     'BINARY',
     'BIT',
     'BLOB',
     'BOOL',
-    'BOOLEAN',                  // numeric-type-overview.html
+    'BOOLEAN',              // numeric-type-overview.html
     'CHAR',
     'CHARACTER',
     'DATE',
@@ -1084,6 +1236,8 @@ $PMA_SQPdata_column_type = array (
     'FLOAT',
     'FLOAT4',
     'FLOAT8',
+    'GEOMETRY',             // spatial
+    'GEOMETRYCOLLECTION',   // spatial
     'INT',
     'INT1',
     'INT2',
@@ -1091,6 +1245,7 @@ $PMA_SQPdata_column_type = array (
     'INT4',
     'INT8',
     'INTEGER',
+    'LINESTRING',           // spatial
     'LONG',
     'LONGBLOB',
     'LONGTEXT',
@@ -1098,10 +1253,15 @@ $PMA_SQPdata_column_type = array (
     'MEDIUMINT',
     'MEDIUMTEXT',
     'MIDDLEINT',
+    'MULTILINESTRING',      // spatial
+    'MULTIPOINT',           // spatial
+    'MULTIPOLYGON',         // spatial
     'NCHAR',
     'NUMERIC',
+    'POINT',                // spatial
+    'POLYGON',              // spatial
     'REAL',
-    'SERIAL',           //BIGINT UNSIGNED NOT NULL AUTO_INCREMENT UNIQUE
+    'SERIAL',               // alsias for BIGINT UNSIGNED NOT NULL AUTO_INCREMENT PRIMARY KEY
     'SET',
     'SMALLINT',
     'TEXT',
@@ -1114,13 +1274,17 @@ $PMA_SQPdata_column_type = array (
     'VARCHAR',
     'YEAR'
 );
-//$PMA_SQPdata_column_type_cnt = count($PMA_SQPdata_column_type);
-$PMA_SQPdata_column_type_cnt = 46;
+/**
+ * $PMA_SQPdata_column_type_cnt = count($PMA_SQPdata_column_type);
+ *
+ * @global integer MySQL column types count
+ */
+$PMA_SQPdata_column_type_cnt = 54;
 
-// check counts
 /*
-foreach ( $GLOBALS as $n => $a ) {
-    echo is_array( $a ) ? $n . ': ' . count( $a ) . '<br />' : '';
+ * check counts
+foreach ($GLOBALS as $n => $a) {
+    echo is_array($a) ? $n . ': ' . count($a) . '<br />' : '';
 }
-*/
+ */
 ?>
