@@ -1,20 +1,22 @@
 <?php
-/* $Id: pdf_schema.php 8941 2006-04-25 15:21:33Z cybot_tm $ */
-// vim: expandtab sw=4 ts=4 sts=4:
+/* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
  * Contributed by Maxime Delorme and merged by lem9
+ *
+ * @version $Id: pdf_schema.php 11625 2008-09-29 17:13:53Z lem9 $
  */
 
 /**
  * Gets some core scripts
  */
-require_once('./libraries/common.lib.php');
+require_once './libraries/common.inc.php';
 
 /**
  * Settings for relation stuff
  */
-require_once('./libraries/relation.lib.php');
-require_once('./libraries/transformations.lib.php');
+require_once './libraries/relation.lib.php';
+require_once './libraries/transformations.lib.php';
+require_once './libraries/Index.class.php';
 
 $cfgRelation = PMA_getRelationsParam();
 
@@ -33,20 +35,12 @@ if (!$cfgRelation['pdfwork']) {
 }
 
 /**
- * Gets the "fpdf" libraries and defines the pdf font path, use unicode version for unicode.
+ * Font used in PDF.
+ *
+ * @todo Make this configuratble (at least Sans/Serif).
  */
-define('FPDF_FONTPATH', './libraries/fpdf/font/');
-if ($charset == 'utf-8') {
-    define('PMA_PDF_FONT', 'FreeSans');
-    require_once('./libraries/fpdf/ufpdf.php');
-    class PMA_FPDF extends UFPDF {
-    };
-} else {
-    define('PMA_PDF_FONT', 'Arial');
-    require_once('./libraries/fpdf/fpdf.php');
-    class PMA_FPDF extends FPDF {
-    };
-}
+define('PMA_PDF_FONT', 'DejaVuSans');
+require_once './libraries/tcpdf/tcpdf.php';
 
 /**
  * Extends the "FPDF" class and prepares the work
@@ -54,7 +48,7 @@ if ($charset == 'utf-8') {
  * @access public
  * @see FPDF
  */
-class PMA_PDF extends PMA_FPDF {
+class PMA_PDF extends TCPDF {
     /**
      * Defines private properties
      */
@@ -63,42 +57,39 @@ class PMA_PDF extends PMA_FPDF {
     var $l_marg = 10;
     var $t_marg = 10;
     var $scale;
-    var $title;
     var $PMA_links;
     var $Outlines = array();
     var $def_outlines;
-    var $Alias ;
+    var $Alias = array();
     var $widths;
 
-    /**
-     * The PMA_PDF constructor
-     *
-     * This function just refers to the "FPDF" constructor: with PHP3 a class
-     * must have a constructor
-     *
-     * @param string $ The page orientation (p, portrait, l or landscape)
-     * @param string $ The unit for sizes (pt, mm, cm or in)
-     * @param mixed $ The page format (A3, A4, A5, letter, legal or an array
-     *                  with page sizes)
-     * @access public
-     * @see FPDF::FPDF()
-     */
-    function PMA_PDF($orientation = 'L', $unit = 'mm', $format = 'A4')
+    public function getFh()
     {
-        $this->Alias = array() ;
-        $this->FPDF($orientation, $unit, $format);
-    } // end of the "PMA_PDF()" method
+        return $this->fh;
+    }
+
+    public function getFw()
+    {
+        return $this->fw;
+    }
+
+    public function setCMargin($c_margin)
+    {
+        $this->cMargin = $c_margin;
+    }
+
     function SetAlias($name, $value)
     {
         $this->Alias[$name] = $value ;
     }
+
     function _putpages()
     {
         if (count($this->Alias) > 0) {
             $nb = $this->page;
             foreach ($this->Alias AS $alias => $value) {
                 for ($n = 1;$n <= $nb;$n++)
-                $this->pages[$n] = $this->_strreplace($alias, $value, $this->pages[$n]);
+                    $this->pages[$n]=str_replace($alias, $value, $this->pages[$n]);
             }
         }
         parent::_putpages();
@@ -132,7 +123,7 @@ class PMA_PDF extends PMA_FPDF {
      * @param double $ The cell width
      * @param double $ The cell height
      * @param string $ The text to output
-     * @param mixed $ Wether to add borders or not
+     * @param mixed $ Whether to add borders or not
      * @param integer $ Where to put the cursor once the output is done
      * @param string $ Align mode
      * @param integer $ Whether to fill the cell with a color or not
@@ -235,9 +226,9 @@ class PMA_PDF extends PMA_FPDF {
         global $server, $lang, $convcharset, $db;
         global $charset, $text_dir, $strRunning, $strDatabase;
 
-        require_once('./libraries/header.inc.php');
+        require_once './libraries/header.inc.php';
 
-        echo '<p><b>PDF - ' . $GLOBALS['strError'] . '</b></p>' . "\n";
+        echo '<p><strong>PDF - ' . $GLOBALS['strError'] . '</strong></p>' . "\n";
         if (!empty($error_message)) {
             $error_message = htmlspecialchars($error_message);
         }
@@ -245,11 +236,11 @@ class PMA_PDF extends PMA_FPDF {
         echo '    ' . $error_message . "\n";
         echo '</p>' . "\n";
 
-        echo '<a href="db_details_structure.php?' . PMA_generate_common_url($db)
+        echo '<a href="db_structure.php?' . PMA_generate_common_url($db)
          . '">' . $GLOBALS['strBack'] . '</a>';
         echo "\n";
 
-        require_once('./libraries/footer.inc.php');
+        require_once './libraries/footer.inc.php';
     } // end of the "PMA_PDF_die()" function
     /**
      * Aliases the "Error()" function from the FPDF class to the
@@ -497,6 +488,8 @@ class PMA_PDF extends PMA_FPDF {
         return $nl;
     }
 } // end of the "PMA_PDF" class
+
+
 /**
  * Draws tables schema
  *
@@ -624,7 +617,7 @@ class PMA_RT_Table {
      * @see PMA_PDF, PMA_RT_Table::PMA_RT_Table_setWidth,
           PMA_RT_Table::PMA_RT_Table_setHeight
      */
-    function PMA_RT_Table($table_name, $ff, &$same_wide_width)
+    function __construct($table_name, $ff, &$same_wide_width, $show_keys)
     {
         global $pdf, $pdf_page_number, $cfgRelation, $db;
 
@@ -635,9 +628,19 @@ class PMA_RT_Table {
             $pdf->PMA_PDF_die(sprintf($GLOBALS['strPdfInvalidTblName'], $table_name));
         }
         // load fields
-        while ($row = PMA_DBI_fetch_row($result)) {
-            $this->fields[] = $row[0];
-        }
+        //check to see if it will load all fields or only the foreign keys
+		if ($show_keys) {
+			$indexes = PMA_Index::getFromTable($this->table_name, $db);
+			$all_columns = array();
+			foreach ($indexes as $index) {
+			   $all_columns = array_merge($all_columns, array_flip(array_keys($index->getColumns())));
+			}
+			$this->fields = array_keys($all_columns);
+		} else {
+	        while ($row = PMA_DBI_fetch_row($result)) {
+	            $this->fields[] = $row[0];
+	        }
+		}
         // height and width
         $this->PMA_RT_Table_setWidth($ff);
         $this->PMA_RT_Table_setHeight();
@@ -757,7 +760,7 @@ class PMA_RT_Relation {
      * @access private
      * @see PMA_RT_Relation::PMA_RT_Relation_getXy
      */
-    function PMA_RT_Relation($master_table, $master_field, $foreign_table, $foreign_field)
+    function __construct($master_table, $master_field, $foreign_table, $foreign_field)
     {
         $src_pos = $this->PMA_RT_Relation_getXy($master_table, $master_field);
         $dest_pos = $this->PMA_RT_Relation_getXy($foreign_table, $foreign_field);
@@ -960,40 +963,30 @@ class PMA_RT {
      *                    everywhere, due to some problems printing with color
      * @param boolean $ Whether to draw grids or not
      * @param boolean $ Whether all tables should have the same width or not
+     * @param boolean $ Wheter to show all field or only the keys
      * @global object   The current PDF document
      * @global string   The current db name
      * @global array    The relations settings
      * @access private
      * @see PMA_PDF
      */
-    function PMA_RT($which_rel, $show_info = 0, $change_color = 0, $show_grid = 0, $all_tab_same_wide = 0, $orientation = 'L', $paper = 'A4')
+    function __construct($which_rel, $show_info = 0, $change_color = 0, $show_grid = 0, $all_tab_same_wide = 0, $orientation = 'L', $paper = 'A4', $show_keys = 0)
     {
         global $pdf, $db, $cfgRelation, $with_doc;
 
         $this->same_wide = $all_tab_same_wide;
         // Initializes a new document
         $pdf = new PMA_PDF('L', 'mm', $paper);
-        $pdf->title = sprintf($GLOBALS['strPdfDbSchema'], $GLOBALS['db'], $which_rel);
-        $pdf->cMargin = 0;
+        $pdf->SetTitle(sprintf($GLOBALS['strPdfDbSchema'], $GLOBALS['db'], $which_rel));
+        $pdf->setCMargin(0);
         $pdf->Open();
-        $pdf->SetTitle($pdf->title);
         $pdf->SetAuthor('phpMyAdmin ' . PMA_VERSION);
         $pdf->AliasNbPages();
-
-        if ($GLOBALS['charset'] == 'utf-8') {
-            // Force FreeSans for utf-8
-            $this->ff = 'FreeSans';
-            $pdf->AddFont('FreeSans', '', 'FreeSans.php');
-            $pdf->AddFont('FreeSans', 'B', 'FreeSansBold.php');
-        } elseif ($GLOBALS['charset'] == 'iso-8859-2') {
-            // fonts added to phpMyAdmin and considered non-standard by fpdf
-            // (Note: those tahoma fonts are iso-8859-2 based)
-            $this->ff == 'tahoma';
-            $pdf->AddFont('tahoma', '', 'tahoma.php');
-            $pdf->AddFont('tahoma', 'B', 'tahomab.php');
-        } else {
-            $this->ff == 'helvetica';
-        }
+        $pdf->AddFont('DejaVuSans', '', 'dejavusans.php');
+        $pdf->AddFont('DejaVuSans', 'B', 'dejavusansb.php');
+        $pdf->AddFont('DejaVuSerif', '', 'dejavuserif.php');
+        $pdf->AddFont('DejaVuSerif', 'B', 'dejavuserifb.php');
+        $this->ff = PMA_PDF_FONT;
         $pdf->SetFont($this->ff, '', 14);
         $pdf->SetAutoPageBreak('auto');
         // Gets tables on this page
@@ -1011,10 +1004,10 @@ class PMA_RT {
         // make doc                    //
         if ($with_doc) {
             $pdf->SetAutoPageBreak('auto', 15);
-            $pdf->cMargin = 1;
+            $pdf->setCMargin(1);
             PMA_RT_DOC($alltables);
             $pdf->SetAutoPageBreak('auto');
-            $pdf->cMargin = 0;
+            $pdf->setCMargin(0);
         }
 
         $pdf->Addpage();
@@ -1031,7 +1024,7 @@ class PMA_RT {
 
         foreach ($alltables AS $table) {
             if (!isset($this->tables[$table])) {
-                $this->tables[$table] = new PMA_RT_Table($table, $this->ff, $this->tablewidth);
+                $this->tables[$table] = new PMA_RT_Table($table, $this->ff, $this->tablewidth, $show_keys);
             }
 
             if ($this->same_wide) {
@@ -1040,7 +1033,12 @@ class PMA_RT {
             $this->PMA_RT_setMinMax($this->tables[$table]);
         }
         // Defines the scale factor
-        $this->scale = ceil(max(($this->x_max - $this->x_min) / ($pdf->fh - $this->r_marg - $this->l_marg), ($this->y_max - $this->y_min) / ($pdf->fw - $this->t_marg - $this->b_marg)) * 100) / 100;
+        $this->scale = ceil(
+            max(
+                ($this->x_max - $this->x_min) / ($pdf->getFh() - $this->r_marg - $this->l_marg),
+                ($this->y_max - $this->y_min) / ($pdf->getFw() - $this->t_marg - $this->b_marg))
+             * 100) / 100;
+
         $pdf->PMA_PDF_setScale($this->scale, $this->x_min, $this->y_min, $this->l_marg, $this->t_marg);
         // Builds and save the PDF document
         $pdf->PMA_PDF_setLineWidthScale(0.1);
@@ -1141,9 +1139,7 @@ function PMA_RT_DOC($alltables)
         $pdf->ln();
 
         $cfgRelation = PMA_getRelationsParam();
-        if ($cfgRelation['commwork'] || PMA_MYSQL_INT_VERSION >= 40100) {
-            $comments = PMA_getComments($db, $table);
-        }
+        $comments = PMA_getComments($db, $table);
         if ($cfgRelation['mimework']) {
             $mime_map = PMA_getMIME($db, $table, true);
         }
@@ -1265,7 +1261,9 @@ function PMA_RT_DOC($alltables)
                 $comments_width = 67;
             } else {
                 // this is really intended for 'letter'
-                // TODO: find optimal width for all formats
+                /**
+                 * @todo find optimal width for all formats
+                 */
                 $comments_width = 50;
             }
             $pdf->Cell($comments_width, 8, ucfirst($GLOBALS['strComments']), 1, 0, 'C');
@@ -1390,8 +1388,9 @@ $all_tab_same_wide      = (isset($all_tab_same_wide) && $all_tab_same_wide == 'o
 $with_doc               = (isset($with_doc) && $with_doc == 'on') ? 1 : 0;
 $orientation            = (isset($orientation) && $orientation == 'P') ? 'P' : 'L';
 $paper                  = isset($paper) ? $paper : 'A4';
+$show_keys              = (isset($show_keys) && $show_keys == 'on') ? 1 : 0;
 PMA_DBI_select_db($db);
 
-$rt = new PMA_RT($pdf_page_number, $show_table_dimension, $show_color, $show_grid, $all_tab_same_wide, $orientation, $paper);
+$rt = new PMA_RT($pdf_page_number, $show_table_dimension, $show_color, $show_grid, $all_tab_same_wide, $orientation, $paper, $show_keys);
 
 ?>
